# simple-repository-browser

A web-based browser for **any** PEP-503 simple python package repository

## Example

Homepage:

![homepage screenshot](https://github.com/simple-repository/simple-repository-browser/blob/main/screenshots/home.png)


Search:

![search result](https://github.com/simple-repository/simple-repository-browser/blob/main/screenshots/search.png)


Project page:

![numpy project page](https://github.com/simple-repository/simple-repository-browser/blob/main/screenshots/project.png)
